<?php

namespace Pinpoint\PackingSlips\Setup;

use Magento\Framework\Setup\ModuleDataSetupInterface;

/**
 * @codeCoverageIgnore
 */
class UpgradeData extends \Pinpoint\Core\Model\Setup\PinpointUpgrade
{
    /**
     * @var \Magento\Eav\Setup\EavSetupFactory
     */
    protected $eavSetupFactory;

    /**
     * UpgradeData constructor.
     * @param \Magento\Eav\Setup\EavSetupFactory $eavSetupFactory
     * @param \Magento\Framework\Module\Dir\Reader $moduleReader
     * @param \Magento\Framework\Xml\Parser $reader
     */
    public function __construct(
        \Magento\Eav\Setup\EavSetupFactory $eavSetupFactory,
        \Magento\Framework\Module\Dir\Reader $moduleReader,
        \Magento\Framework\Xml\Parser $reader
    ) {
        $this->eavSetupFactory = $eavSetupFactory;

        parent::__construct($moduleReader, $reader);
    }

    public function upgrade_0_0_2(ModuleDataSetupInterface $setup)
    {
        $setup->startSetup();

        $eavSetup = $this->eavSetupFactory->create(['setup' => $setup]);

        $eavSetup->removeAttribute(\Magento\Catalog\Model\Product::ENTITY, 'required_machines');
        $eavSetup->addAttribute(
            \Magento\Catalog\Model\Product::ENTITY,
            'required_machines',
            [
                'group' => 'Machines',
                'type' => 'varchar',
                'backend' => '',
                'frontend' => '',
                'label' => 'Required Machines',
                'input' => 'multiselect',
                'class' => '',
                'source' => 'Pinpoint\PackingSlips\Model\Config\Source\Options',
                'global' => \Magento\Eav\Model\Entity\Attribute\ScopedAttributeInterface::SCOPE_GLOBAL,
                'visible' => true,
                'required' => true,
                'user_defined' => false,
                'default' => '',
                'searchable' => false,
                'filterable' => false,
                'comparable' => false,
                'visible_on_front' => false,
                'used_in_product_listing' => true,
                'unique' => false
            ]
        );

        $setup->endSetup();
    }

    public function upgrade_0_0_3(ModuleDataSetupInterface $setup)
    {
        $setup->startSetup();

        $eavSetup = $this->eavSetupFactory->create(['setup' => $setup]);

        $eavSetup->removeAttribute(\Magento\Catalog\Model\Product::ENTITY, 'required_machines');
        $eavSetup->addAttribute(
            \Magento\Catalog\Model\Product::ENTITY,
            'required_machines',
            [
                'type' => 'varchar',
                'backend' => 'Magento\Eav\Model\Entity\Attribute\Backend\ArrayBackend',
                'frontend' => '',
                'label' => 'Required Machines',
                'input' => 'multiselect',
                'class' => '',
                'source' => '',
                'global' => \Magento\Eav\Model\Entity\Attribute\ScopedAttributeInterface::SCOPE_GLOBAL,
                'visible' => true,
                'required' => false,
                'user_defined' => true,
                'default' => null,
                'searchable' => false,
                'filterable' => false,
                'comparable' => false,
                'visible_on_front' => false,
                'used_in_product_listing' => false,
                'unique' => false,
                'apply_to' => '',
                'system' => 1,
                'group' => 'General',
                'option' => array('values' => array("B1 – R1","B2 – R2","B3 – R3","B4 – R4","B5 – TF1","B6 – F1","B7 – F2","B8 – EF1","B9 – Z1","B10 – EF2","B11 – FC1","B12 – RP1"))
            ]
        );

        $setup->endSetup();
    }
}